@@ -48,7 +48,7 @@ def file_create_input(check_exist=True, symbols=['XBTUSD'], broker='bitmex', str
     setting_path = os.path.join(settings_path, setting_name)
     if check_exist and os.path.exists(setting_path):
         settings = pickle.load(open(setting_path, 'rb'))
-        return check_settings(settings, broker)
+        return check_settings(settings, symbols, broker, strategy)
     else:
         token = input(
             "Submit your Strategytoken (found in your member area): ")
